#!/bin/bash
#
#  Created by Maksim Rogov on Mon Feb 01 2005.
#  Copyright 2005 Nullriver, Inc. All rights reserved.

#  <1:source> <2:destination> <3:videoresolution> <4:videoquality> <5:audioquality> <6:usequicktime> <7:deinterlace>

if [ ! $7 ]; then 
	echo "Wrong parameter count!"
	exit 1; 
fi;

echo "Using MPEG-4 compression..."

# Set video resolution
case $3 in
	0)
	VIDEO_RESOLUTION="320x240";
	ASPECT="4:3";;
	1)
	VIDEO_RESOLUTION="320x180";
	ASPECT="16:9";;
	2)
	VIDEO_RESOLUTION="480x480";
	ASPECT="1:1";;
esac

# Set video quality
case $4 in
	0)
	FRAME_RATE=15;
	VIDEO_BITRATE=192;
	HIGH_QUALITY=false;;
	1)
	FRAME_RATE=30;
	VIDEO_BITRATE=512;
	HIGH_QUALITY=false;;
	2)
	FRAME_RATE=30;
	VIDEO_BITRATE=1024;
	HIGH_QUALITY=false;;
	3)
	FRAME_RATE=30;
	VIDEO_BITRATE=1536;
	HIGH_QUALITY=true;;
	4)
	FRAME_RATE=30;
	VIDEO_BITRATE=2500;
	HIGH_QUALITY=true;;
esac

# Set audio quality
case $5 in
	0)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=32;;
	1)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=48;;
	2)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=64;;
	3)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=128;;
	4)
	AUDIO_HZ=48000;
	AUDIO_BITRATE=64;;
esac

# Set whether we use quicktime decoding
case $6 in
	0)
	USE_QUICKTIME=false;;
	1)
	USE_QUICKTIME=true;;
esac

# Set whether we should deinterlace
case $7 in
	0)
	DEINTERLACE=false;;
	1)
	DEINTERLACE=true;;
esac

##################################################

# Prepare
if [ $HIGH_QUALITY == true ]; then
	HQ_MODIFIER="-hq";
fi

if [ $DEINTERLACE == true ]; then
	DEINTERLACE_MODIFIER="-deinterlace";
fi

PREFIX="./ffmpeg -i \"${1}\""

if [ $USE_QUICKTIME == true ]; then
	./movtowav -o /tmp/MoviePod.wav "$1"
	if [ -s /tmp/MoviePod.wav ]; then
		PREFIX="./movtoy4m -a ${ASPECT} \"${1}\" | ./ffmpeg -f wav -ac 2 -i /tmp/MoviePod.wav -f yuv4mpegpipe -i -"
		echo MOVINFO: `./movinfo "$1"` :MOVINFO
	fi
fi

# Begin conversion
POSTFIX="-f mp4									\
		-vcodec mpeg4							\
		-acodec aac								\
		-ac 2									\
		-qmin 3									\
		-qmax 15								\
		-ar ${AUDIO_HZ}							\
		-ab ${AUDIO_BITRATE}					\
		-g 300									\
		-b ${VIDEO_BITRATE}						\
		-r ${FRAME_RATE}						\
		-s ${VIDEO_RESOLUTION}					\
		-aspect ${ASPECT}						\
		${HQ_MODIFIER}							\
		${DEINTERLACE_MODIFIER}					\
		-threads 4								\
		-y										\
		\"${2}\""

eval "${PREFIX} ${POSTFIX}" || exit 1;

# Create thumb file
./movtoy4m -a ${ASPECT} "$2" | ./ffmpeg -f yuv4mpegpipe -i - -y -s 80x60 -r 1 -t 1 -ss 3 -an -f mjpeg "$2.JPG" || exit 1;

# Clean up
if [ -f /tmp/MoviePod.wav ]; then
	rm -f /tmp/MoviePod.wav;
fi